Package: FamEvent
Type: Package
Title: Family Age-at-Onset Data Simulation and Penetrance Estimation
Version: 3.3
Date: 2026-05-14
Authors@R: c(
    person(given = "Yun-Hee",
           family = "Choi",
           role = c("aut", "cre"),
           email = "yun-hee.choi@schulich.uwo.ca"),
    person(given = "Karen",
           family = "Kopciuk",
           role = "aut"),
    person(given = "Wenqing",
           family = "He",
           role = "aut"),
    person(given = "Laurent",
           family = "Briollais",
           role = "aut"))
Description: Simulates age-at-onset traits associated with a segregating major gene in family data 
     obtained from population-based, clinic-based, or multi-stage designs. Appropriate ascertainment 
     correction is utilized to estimate age-dependent penetrance functions either parametrically from 
     the fitted model or nonparametrically from the data. The Expectation and Maximization algorithm 
     can infer missing genotypes and carrier probabilities estimated from family's genotype and
     phenotype information or from fitted models. Plot functions include pedigrees of simulated 
     families and predicted penetrance curves based on specified parameter values.
     For more information see Choi, Y.-H., Briollais, L., He, W. and Kopciuk, K. (2021) FamEvent: An 
     R Package for Generating and Modeling Time-to-Event Data in Family Designs, 
     Journal of Statistical Software 97 (7), 1-30.
License: GPL (>= 2)
Encoding: UTF-8
LazyData: true
Depends: R (>= 3.3.0), survival
Imports: MASS, stats, kinship2, truncnorm, eha, pracma, cmprsk,
        matrixcalc
NeedsCompilation: no
URL: https://CRAN.R-project.org/package=FamEvent
Packaged: 2026-05-14 21:23:04 UTC; yunheechoi
Author: Yun-Hee Choi [aut, cre],
  Karen Kopciuk [aut],
  Wenqing He [aut],
  Laurent Briollais [aut]
Maintainer: Yun-Hee Choi <yun-hee.choi@schulich.uwo.ca>
Repository: CRAN
Date/Publication: 2026-05-14 21:40:29 UTC
Built: R 4.5.2; ; 2026-05-14 23:57:04 UTC; unix
